[PATCH 6/7] staging: comedi: pcl730: add support for the P8R8-DIO ISA board

H Hartley Sweeten hsweeten at visionengravers.com
Thu Jun 6 22:39:09 UTC 2013


The ICP P8R8-DIO ISA boards can be supported by this driver. This board
has 8 isolated digital outputs and 8 isolated digital outputs.

Add support for this board to the pcl730 driver.

Signed-off-by: H Hartley Sweeten <hsweeten at visionengravers.com>
Cc: Ian Abbott <abbotti at mev.co.uk>
Cc: Greg Kroah-Hartman <gregkh at linuxfoundation.org>
---
 drivers/staging/comedi/Kconfig          |  1 +
 drivers/staging/comedi/drivers/pcl730.c | 13 +++++++++++--
 2 files changed, 12 insertions(+), 2 deletions(-)

diff --git a/drivers/staging/comedi/Kconfig b/drivers/staging/comedi/Kconfig
index a7c0d63..8c8a551 100644
--- a/drivers/staging/comedi/Kconfig
+++ b/drivers/staging/comedi/Kconfig
@@ -147,6 +147,7 @@ config COMEDI_PCL730
 	  ADlink ACL-7130     isolated - 16 in/16 out  ttl - 16 in/16 out
 	  Advantech PCM-3730  isolated - 8 in/8 out    ttl - 16 in/16 out
 	  Advantech PCL-725   isolated - 8 in/8 out
+	  ICP P8R8-DIO        isolated - 8 in/8 out
 	  ADlink ACL-7225b    isolated - 16 in/16 out
 	  ICP P16R16-DIO      isolated - 16 in/16 out
 	  Advantech PCL-733   isolated - 32 in
diff --git a/drivers/staging/comedi/drivers/pcl730.c b/drivers/staging/comedi/drivers/pcl730.c
index d3bdf74..f9e9927 100644
--- a/drivers/staging/comedi/drivers/pcl730.c
+++ b/drivers/staging/comedi/drivers/pcl730.c
@@ -12,6 +12,7 @@
  *	    (Adlink) ACL-7130 [acl7130]
  *	    (Advantech) PCM-3730 [pcm3730]
  *	    (Advantech) PCL-725 [pcl725]
+ *	    (ICP) P8R8-DIO [p16r16dio]
  *	    (Adlink) ACL-7225b [acl7225b]
  *	    (ICP) P16R16-DIO [p16r16dio]
  *	    (Advantech) PCL-733 [pcl733]
@@ -35,8 +36,8 @@
  *
  * The pcm3730 PC/104 board does not have the PCL730_IDIO_HI register.
  * The pcl725 ISA board uses separate registers for isolated digital I/O.
  * The acl7225b and p16r16dio boards have isolated digital output readback
  * and separate registers for isolated digital I/O.
  * The pcl733 ISA board uses all four registers for isolated digital inputs.
  * The pcl734 ISA board uses all four registers for isolated digital outputs.
  */
@@ -98,6 +99,14 @@ static const struct pcl730_board pcl730_boards[] = {
 		.n_iso_out_chan	= 8,
 		.n_iso_in_chan	= 8,
 	}, {
+		.name		= "p8r8dio",
+		.io_range	= 0x02,
+		.is_pcl725	= 1,
+		.has_readback	= 1,
+		.n_subdevs	= 2,
+		.n_iso_out_chan	= 8,
+		.n_iso_in_chan	= 8,
+	}, {
 		.name		= "acl7225b",
 		.io_range	= 0x08,		/* only 4 are used */
 		.is_acl7225b	= 1,
@@ -35,8 +36,8 @@
  * The pcm3730 PC/104 board does not have the PCL730_IDIO_HI register.
  * The pcl725 ISA board uses separate registers for isolated digital I/O.
- * The acl7225b and p16r16dio boards have isolated digital output readback
- * and separate registers for isolated digital I/O.
+ * The p8r8dio, acl7225b, and p16r16dio boards have isolated digital output
+ * readback and separate registers for isolated digital I/O.
  * The pcl733 ISA board uses all four registers for isolated digital inputs.
  * The pcl734 ISA board uses all four registers for isolated digital outputs.
-- 
1.8.1.4




More information about the devel mailing list